@@ -34,7 +34,7 @@ options = ['strict', 'partly', 'all']
 sort = ['relevence', 'date']
 
 app = dash.Dash(external_stylesheets=[dbc.themes.BOOTSTRAP])
-app.title = 'paper-search'
+app.title = 'arxivbox'
 
 
 if not os.path.isfile('logfav'):
@@ -61,8 +61,13 @@ app.layout = dbc.Container([html.Br(),
     html.Br(),
     (html.Div(id='my-output')),
     html.Div(id='dummy'),
-    loading(html.Div(id='loadig'))
-
+    loading(html.Div(id='loadig')),
+    dbc.Tooltip('Show marked publications', target="check-all"),
+    dbc.Tooltip('Select conference name',target="select"),
+    dbc.Tooltip('Select maximum results',target="select_max"),
+    dbc.Tooltip('Select matching algorithm',target="select_option"),
+    dbc.Tooltip('Sort by', target="select_sort"),
+    dbc.Tooltip('Show results based on code availability', target="code_option"),
 
 ], style =  {'align':'center', 'width':'800px'})
 
